@@ -147,6 +147,20 @@ void AtlanticDesigner::initBoard()
 
 	board->show();
 	editor->show();
+
+	initToken();
+}
+
+void AtlanticDesigner::initToken()
+{
+	if (!m_player)
+		m_player = new Player(0);
+	else
+		m_player->setLocation(0);
+	
+	board->addToken(m_player);
+
+	connect(m_player, SIGNAL(changed(Player *)), board, SLOT(playerChanged(Player *)));
 }
 
 void AtlanticDesigner::openNew()
@@ -546,11 +560,6 @@ void AtlanticDesigner::updateJumpMenu()
 
 void AtlanticDesigner::setPlayerAtBeginning()
 {
-	delete m_player;
-
-	// our superstar!
-	m_player = new Player(0);
-
 	ConfigEstate *go = 0;
 	for (go = estates.first(); go; go = estates.next())
 		if (go->go())
@@ -560,8 +569,6 @@ void AtlanticDesigner::setPlayerAtBeginning()
 		go = estates.first();
 
 	movePlayer(go);
-	board->addToken(m_player);
-
 	editor->setEstate(go);
 }
 
