@@ -9,7 +9,7 @@ int main(int argc, char *argv[])
 {
 	KAboutData aboutData(
 	           "atlantikdesigner",
-	           I18N_NOOP("Atlantik Designer"), "1.0",
+	           I18N_NOOP("Atlantik Designer"), "1.0.1",
 	           I18N_NOOP("Atlantik gameboard designer"),
 	           KAboutData::License_GPL,
 	           I18N_NOOP("(c) 2002 Jason Katz-Brown"),
