@@ -5,23 +5,23 @@
    modify it under the terms of the GNU General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
- 
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.
- 
+
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
 
-$Id: kolourpicker.cpp,v 1.7 2001/12/11 23:53:55 molnarc Exp $
+$Id: kolourpicker.cpp,v 1.9 2002/07/03 10:18:06 binner Exp $
 */
 
 #include <qfile.h>
 #include <qtextstream.h>
-#include <qlayout.h> 
+#include <qlayout.h>
 #include <qpushbutton.h>
 #include <qimage.h>
 #include <qclipboard.h>
@@ -31,13 +31,13 @@ $Id: kolourpicker.cpp,v 1.7 2001/12/11 23:53:55 molnarc Exp $
 #include <qtooltip.h>
 #include <qcursor.h>
 
-#include <kglobal.h> 
+#include <kglobal.h>
 #include <klocale.h>
 #include <kiconloader.h>
 #include <kinstance.h>
 #include <kconfig.h>
 #include <kaboutdata.h>
-#include <kaboutapplication.h> 
+#include <kaboutapplication.h>
 #include <kmessagebox.h>
 #include <kpopupmenu.h>
 
@@ -153,7 +153,7 @@ void KolourPicker::slotHistory()
 		conf->sync();
 	}
 	else if (id != -1)
-		QApplication::clipboard()->setText(popup.findItem(id)->text());
+		setClipboard(popup.findItem(id)->text());
 }
 
 void KolourPicker::mouseReleaseEvent(QMouseEvent *e)
@@ -168,6 +168,12 @@ void KolourPicker::mouseReleaseEvent(QMouseEvent *e)
 			e->globalPos().x(), e->globalPos().y(), 1, 1);
 		QImage img = pm.convertToImage();
 		QColor color(img.pixel(0, 0));
+
+		// eventually remove a dupe
+		QValueListIterator<QColor> dupe = m_history.find(color);
+		if (dupe != m_history.end())
+			m_history.remove(dupe);
+
 		m_history.append(color);
 		while (m_history.count() >= 10)
 			m_history.remove(m_history.begin());
@@ -188,13 +194,25 @@ void KolourPicker::mouseReleaseEvent(QMouseEvent *e)
 		QPopupMenu *popup = copyPopup(color, true);
 		int id = popup->exec(e->globalPos());
 		if (id != -1)
-			QApplication::clipboard()->setText(popup->findItem(id)->text());
+			setClipboard( popup->findItem(id)->text() );
 		delete popup;
 	}
 	else
 		KPanelApplet::mouseReleaseEvent(e);
 }
 
+// set both clipboard and selection
+void KolourPicker::setClipboard(const QString& text)
+{
+	QClipboard *clip = QApplication::clipboard();
+	bool oldMode = clip->selectionModeEnabled();
+	clip->setSelectionMode(true);
+	clip->setText(text);
+	clip->setSelectionMode(false);
+	clip->setText(text);
+	clip->setSelectionMode( oldMode );
+}
+
 void KolourPicker::keyPressEvent(QKeyEvent *e)
 {
 	if (m_picking)
@@ -232,7 +250,7 @@ void KolourPicker::arrangeButtons()
 			{
 				p = (h - 40)/3;
 				m_colourButton->setGeometry(0, p, 20, 20);
-				m_historyButton->setGeometry(0, 2*p+20, 20, 20); 
+				m_historyButton->setGeometry(0, 2*p+20, 20, 20);
 			}
 		}
 		else
@@ -240,7 +258,7 @@ void KolourPicker::arrangeButtons()
 			// horizontal layout
 			p = (h - 20)/2;
 			m_colourButton->setGeometry(0, p, 20, 20);
-			m_historyButton->setGeometry(22, p, 20, 20); 
+			m_historyButton->setGeometry(22, p, 20, 20);
 		}
 	}
 	else
@@ -255,7 +273,7 @@ void KolourPicker::arrangeButtons()
 			{
 				p = (w - 40)/3;
 				m_colourButton->setGeometry(p, 0, 20, 20);
-				m_historyButton->setGeometry(2*p+20, 0, 20, 20); 
+				m_historyButton->setGeometry(2*p+20, 0, 20, 20);
 			}
 		}
 		else
@@ -263,7 +281,7 @@ void KolourPicker::arrangeButtons()
 			// vertical layout
 			p = (w - 20)/2;
 			m_colourButton->setGeometry(p, 0, 20, 20);
-			m_historyButton->setGeometry(p, 22, 20, 20); 
+			m_historyButton->setGeometry(p, 22, 20, 20);
 		}
 	}
 
@@ -274,7 +292,7 @@ QPopupMenu *KolourPicker::copyPopup(const QColor &c, bool title) const
 {
 	KPopupMenu *popup = new KPopupMenu;
 	if (title)
-		popup->insertTitle(colorPixmap(c), i18n("Copy color value"));
+		popup->insertTitle(colorPixmap(c), i18n("Copy Color Value"));
 	QString value;
 	// r, g, b
 	value.sprintf("%u, %u, %u", c.red(), c.green(), c.blue());
