@@ -23,15 +23,16 @@
 #include <kmessagebox.h>
 
 #include "confdlg.h"
-#include "confdlg.moc"
 #include "timemon.h"
 
 // -- KConfDialog definition ---------------------------------------------
 
 KConfDialog::KConfDialog(KTimeMon *t)
-    : timemon(t), haveWarned(false)
+    : KDialogBase( Tabbed, i18n("KTimeMon Configuration" ),
+          Ok|Cancel|Apply, Ok ),
+      timemon(t)
 {
-    QWidget *w;
+    QFrame *page;
     QBoxLayout *bl;
     QGridLayout *gl;
     QLabel *l;
@@ -39,22 +40,22 @@ KConfDialog::KConfDialog(KTimeMon *t)
     KColorButton *cb;
     unsigned i, j;
 
-    setCaption(i18n("KTimeMon Configuration"));
+    setIcon( SmallIcon( "ktimemon" ) );
 
     // first tab: general
-    w = new QWidget(this);
+    page = addPage( i18n( "&General" ) );
 
-    bl = new QVBoxLayout(w, 5);
+    bl = new QVBoxLayout(page, 5);
 
-    b = new QVGroupBox(i18n("Sample &Rate:"), w);
+    b = new QVGroupBox(i18n("Sample &Rate"), page);
     bl->addWidget(b);
 
     intervalEdit = new KIntNumInput(250, b);
     intervalEdit->setRange(20, 1000, 10);
-    intervalEdit->setSuffix(i18n("ms"));
+    intervalEdit->setSuffix(i18n(" msec"));
 
     // scaling group box
-    b = new QVGroupBox(i18n("Scaling"), w);
+    b = new QVGroupBox(i18n("Scaling"), page);
     bl->addWidget(b, 5);
 
     autoScaleBox = new QCheckBox(i18n("&Automatic"), b);
@@ -69,18 +70,15 @@ KConfDialog::KConfDialog(KTimeMon *t)
     swapScaleEdit->setLabel(i18n("&Swapping:"), AlignVCenter | AlignLeft);
 
     ctxScaleEdit  = new KIntNumInput(swapScaleEdit, 10000, b);
-    ctxScaleEdit->setLabel(i18n("&Context Switch:"), AlignVCenter | AlignLeft);
+    ctxScaleEdit->setLabel(i18n("&Context switch:"), AlignVCenter | AlignLeft);
     ctxScaleEdit->setRange(1, 10000, 30);
 
     bl->addStretch(1);
 
-    addTab(w, i18n("&General"));
-
-
     // second tab: colours
-    w = new QWidget(this);
+    page = addPage( i18n( "C&olors" ) );
 
-    gl = new QGridLayout(w, 12, 10, 5);
+    gl = new QGridLayout(page, 12, 10, 5);
 
     gl->setColStretch(3, 1); gl->setColStretch(6, 1); // eat up horizontal space
     gl->setRowStretch(11, 1);	// eat up vertical space
@@ -91,33 +89,34 @@ KConfDialog::KConfDialog(KTimeMon *t)
     gl->addColSpacing(0, 10); gl->addColSpacing(9, 25);
 
     QString colourLabels[2][3];
-    colourLabels[0][0] = i18n("Kernel");
-    colourLabels[0][1] = i18n("User");
+    colourLabels[0][0] = i18n("Kernel:");
+    colourLabels[0][1] = i18n("User:");
 #if defined(__sun__)
-    colourLabels[0][2] = i18n("Wait");
+    colourLabels[0][2] = i18n("Wait:");
 #else
-    colourLabels[0][2] = i18n("Nice");
+    colourLabels[0][2] = i18n("Nice:");
 #endif
 
-    colourLabels[1][0] = i18n("Used");
-    colourLabels[1][1] = i18n("Buffers");
+    colourLabels[1][0] = i18n("Used:");
+    colourLabels[1][1] = i18n("Buffers:");
 #if defined(__sun__) || defined(__osf__)
-    colourLabels[1][2] = i18n("Kernel");
+    colourLabels[1][2] = i18n("Kernel:");
 #else
-    colourLabels[1][2] = i18n("Cached");
+    colourLabels[1][2] = i18n("Cached:");
 #endif
 #
     KColorButton **colourButtons[2][3] = { { &kernelCB, &userCB, &niceCB },
                                            { &usedCB, &buffersCB, &cachedCB }};
     for (i = 0; i < 2; i++) {
-        b = new QGroupBox((i ? i18n("Memory/Swapping") : i18n("CPU/Paging")), w);
+        b = new QGroupBox((i ? i18n("Memory/Swapping")
+                             : i18n("CPU/Paging")), page);
         gl->addMultiCellWidget(b, 4*i, 4*i+2, 0, 9);
 
         for (j = 0; j < 3; j++) {
-            l = new QLabel(colourLabels[i][j], w);
+            l = new QLabel(colourLabels[i][j], page);
             gl->addWidget(l, 4*i+1, 3*j+1, AlignVCenter | AlignRight);
 
-            cb = *colourButtons[i][j] = new KColorButton(white, w);
+            cb = *colourButtons[i][j] = new KColorButton(white, page);
             gl->addWidget(cb, 4*i+1, 3*j+2, AlignCenter);
 
             connect(cb, SIGNAL(changed(const QColor &)),
@@ -125,70 +124,67 @@ KConfDialog::KConfDialog(KTimeMon *t)
         }
     }
 
-    b = new QGroupBox(i18n("Swap/Background"), w);
+    b = new QGroupBox(i18n("Swap/Background"), page);
     gl->addMultiCellWidget(b, 8, 10, 0, 6);
 
-    l = new QLabel(i18n("Swap"), w);
+    l = new QLabel(i18n("Swap:"), page);
     gl->addWidget(l, 9, 1, AlignVCenter | AlignRight);
 
-    cb = swapCB = new KColorButton(red, w);
+    cb = swapCB = new KColorButton(red, page);
     gl->addWidget(cb, 9, 2);
 
     connect(cb, SIGNAL(changed(const QColor &)),
             this, SLOT(updateSampleWidget(const QColor &)));
 
-    l = new QLabel(i18n("Backgd"), w);
+    l = new QLabel(i18n("Backgd:"), page);
     gl->addWidget(l, 9, 4, AlignVCenter | AlignRight);
 
-    cb = bgCB = new KColorButton(blue, w);
+    cb = bgCB = new KColorButton(blue, page);
     gl->addWidget(cb, 9, 5);
 
   connect(cb, SIGNAL(changed(const QColor &)),
 	  this, SLOT(updateSampleWidget(const QColor &)));
 
-  b = new QGroupBox(i18n("Sample"), w);
-  gl->addMultiCellWidget(b, 8, 10, 7, 9);
-
-//  sample = new KTimeMonWidget(0, false, true, b);
-//  sample->setGeometry(38, 25, 35, 35);
-
-  addTab(w, i18n("&Colors"));
-
+  //b = new QGroupBox(i18n("Sample"), page);
+  //gl->addMultiCellWidget(b, 8, 10, 7, 9);
 
   // third tab: interaction
-  w = new QWidget(this);
-  addTab(w, i18n("&Interaction"));
+  page = addPage( i18n( "&Interaction" ) );
 
-  bl = new QVBoxLayout(w, 5);
+  bl = new QVBoxLayout(page, 5);
 
-  b = new QGroupBox(i18n("Mouse Events"), w);
+  b = new QGroupBox(i18n("Mouse Events"), page);
+  b->setColumnLayout( 0, Qt::Vertical );
   bl->addWidget(b, 5);
 
-  gl = new QGridLayout(b, MAX_MOUSE_ACTIONS + 1, 3, 10);
+  QVBoxLayout *vbox = new QVBoxLayout( b->layout() );
+
+  gl = new QGridLayout(b, MAX_MOUSE_ACTIONS + 1, 3, 0, 6 );
+
+  vbox->addLayout( gl );
 
   for (i = 1; i < MAX_MOUSE_ACTIONS + 1; i++)
     gl->setRowStretch(i, 1);
   gl->setColStretch(2, 1);
-  gl->setMargin( 11 );
 
-  QString buttonText[MAX_MOUSE_ACTIONS] = { i18n("Left button"),
-						i18n("Middle button"),
-						i18n("Right button") };
+  QString buttonText[MAX_MOUSE_ACTIONS] = { i18n("Left button:"),
+						i18n("Middle button:"),
+						i18n("Right button:") };
+
   for (i = 0; i < (int) MAX_MOUSE_ACTIONS; i++) {
 
     l = new QLabel(buttonText[i], b);
     gl->addWidget(l, i+1, 0);
 
     mouseC[i] = new QComboBox(false, b);
-    mouseC[i]->insertItem(i18n("is ignored"), KTimeMon::NOTHING);
-    mouseC[i]->insertItem(i18n("switches mode"), KTimeMon::SWITCH);
-    mouseC[i]->insertItem(i18n("pops up menu"), KTimeMon::MENU);
-    mouseC[i]->insertItem(i18n("starts"), KTimeMon::COMMAND);
-    mouseC[i]->setCurrentItem(t->mouseAction[i]);
+    mouseC[i]->insertItem(i18n("Is Ignored"), KTimeMon::NOTHING);
+    mouseC[i]->insertItem(i18n("Switches Mode"), KTimeMon::SWITCH);
+    mouseC[i]->insertItem(i18n("Pops Up Menu"), KTimeMon::MENU);
+    mouseC[i]->insertItem(i18n("Starts"), KTimeMon::COMMAND);
     gl->addWidget(mouseC[i], i+1, 1);
 
-    connect(mouseC[i], SIGNAL(activated(int)), this,
-	    SLOT(mouseInteraction(int)));
+    connect( mouseC[ i ], SIGNAL( activated( int ) ), this,
+           SLOT( mouseCommandEnable() ) );
 
     mouseLE[i] = new KLineEdit(b);
     mouseLE[i]->setText(t->mouseActionCommand[i]);
@@ -197,26 +193,17 @@ KConfDialog::KConfDialog(KTimeMon *t)
 
   gl->activate();
 
-  mouseInteraction(0);		// update enable/disable etc
-
-  b = new QVGroupBox(i18n("Tool Tips"), w);
+  b = new QVGroupBox(i18n("Tooltips"), page);
   bl->addWidget(b, 5);
 
-  toolTipBox = new QCheckBox(i18n("Tool Tips enabled"), b);
+  toolTipBox = new QCheckBox(i18n("Tooltips enabled"), b);
 
   bl->addStretch(1);
 
-  setApplyButton();
-  setCancelButton();
   resize(380, 300);
 
-  connect(this, SIGNAL(applyButtonPressed()), timemon, SLOT(apply()));
-}
-
-void KConfDialog::accept()
-{
-    timemon->writeConfiguration();
-    QTabDialog::accept();
+  connect(this, SIGNAL(applyClicked()), timemon, SLOT(apply()));
+  connect(this, SIGNAL(okClicked()), timemon, SLOT(apply()));
 }
 
 // Adjust the colours of the sample widget in the configuration dialog.
@@ -245,38 +232,15 @@ void KConfDialog::toggle(bool state)
     ctxScaleEdit->setEnabled(!state);
 }
 
-
-// -----------------------------------------------------------------------------
-
-// Check for valid settings.
-void KConfDialog::mouseInteraction(int)
+void KConfDialog::mouseCommandEnable()
 {
-  int i;
-  bool menuOk = false;
+  for ( int i = 0; i < MAX_MOUSE_ACTIONS; i++ ) {
+    unsigned action = mouseC[ i ]->currentItem();
 
-  for (i = 0; i < MAX_MOUSE_ACTIONS; i++) {
-    unsigned action = mouseC[i]->currentItem();
-
-    if (action == KTimeMon::MENU) menuOk = true;
-    mouseLE[i]->setEnabled(action == KTimeMon::COMMAND);
+    mouseLE[ i ]->setEnabled( action == KTimeMon::COMMAND );
   }
-
-  if (!menuOk && !haveWarned) {
-    KMessageBox::information(timemon, i18n("KTimeMon notice"),
-			 i18n("You have set the configuration so that "
-			      "the pop-up menu cannot be invoked by a "
-			      "mouse click. This is probably not such a "
-			      "good idea, because you will have to edit "
-			      "the configuration options manually to get "
-			      "rid of this setting..."));
-    haveWarned = true;
-  }
-
 }
 
-
-// -----------------------------------------------------------------------------
-
 // update the dialog fields
 void KConfDialog::update()
 {
@@ -293,6 +257,13 @@ void KConfDialog::update()
   swapScaleEdit->setValue(timemon->swapScale);
   ctxScaleEdit->setValue(timemon->ctxScale);
   autoScaleBox->setChecked(timemon->autoScale);
+
+  for ( int i = 0; i < MAX_MOUSE_ACTIONS; i++ )
+    mouseC[i]->setCurrentItem(timemon->mouseAction[i]);
+  mouseCommandEnable();
+
   toolTipBox->setChecked(timemon->tooltip);
   updateSampleWidget(white);	// fake colour
 }
+
+#include "confdlg.moc"
