@@ -22,6 +22,7 @@
 #include <klibloader.h>
 
 class KURL;
+namespace KIO { class Job; }
 
 class PluginBabelFish : public KParts::Plugin
 {
@@ -33,6 +34,11 @@ public:
 
 public slots:
   void translateURL();
+protected slots:
+  void slotStarted( KIO::Job* );
+
+private:
+  KActionMenu* m_menu;
 };
 
 #endif
