@@ -16,7 +16,7 @@
  *                                                                         *
  ***************************************************************************/
 
-/* $Id: domtreeview.cpp,v 1.20 2002/02/10 14:31:02 schlpbch Exp $ */
+/* $Id: domtreeview.cpp,v 1.27 2002/08/25 09:51:01 mlaurent Exp $ */
 
 #include <assert.h>
 
@@ -28,6 +28,7 @@
 
 #include <dom/dom_element.h>
 #include <dom/dom_node.h>
+#include <dom/dom_exception.h>
 
 #include <kfiledialog.h>
 #include <kmessagebox.h>
@@ -71,7 +72,7 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
   m_hLayout1->addWidget( m_pureCheckBox );
 
   m_showAttributesCheckBox = new QCheckBox( this );
-  m_showAttributesCheckBox->setText( i18n( "Show &Attributes" ) );
+  m_showAttributesCheckBox->setText( i18n( "Show &attributes" ) );
   m_showAttributesCheckBox->setChecked(m_bShowAttributes);
   connect(m_showAttributesCheckBox, SIGNAL(toggled(bool)), this,
 	  SLOT(slotShowAttributesToggled(bool)));
@@ -105,7 +106,7 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
   m_hLayout2->setMargin( 2 );
 
   m_findButton = new QPushButton( this );
-  m_findButton->setText( i18n( "&Find" ) );
+  m_findButton->setText( i18n( "&Find..." ) );
   connect(m_findButton, SIGNAL(clicked()), this, SLOT(slotFindClicked()));
   m_hLayout2->addWidget( m_findButton );
 
@@ -114,7 +115,7 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
 
   if (allowSaving) {
     m_saveButton = new QPushButton( this );
-    m_saveButton->setText( i18n( "&Save as HTML" ) );
+    m_saveButton->setText( i18n( "&Save as HTML..." ) );
     connect(m_saveButton, SIGNAL(clicked()), this, SLOT(slotSaveClicked()));
     m_hLayout2->addWidget( m_saveButton );
   }
@@ -136,7 +137,7 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
   const QFont font(KGlobalSettings::generalFont());
   m_listView->setFont( font );
   m_listView->setRootIsDecorated(true);
-  m_listView->addColumn("DOM-Tree");
+  m_listView->addColumn(i18n("DOM Tree"));
   m_listView->setSorting(-1);
   m_rootListView = m_listView;
 
@@ -149,6 +150,7 @@ DOMTreeView::DOMTreeView(QWidget *parent, KHTMLPart *_part, const char* name, bo
   m_nodedict.setAutoDelete(true);
 
   slotShowTree(part->document());
+  updateIncrDecreaseButton();
 }
 
 DOMTreeView::~DOMTreeView()
@@ -167,11 +169,21 @@ void DOMTreeView::slotShowNode(const DOM::Node &pNode)
 
 void DOMTreeView::slotShowTree(const DOM::Node &pNode)
 {
+  DOM::Node child;
+
   m_listView->clear();
   m_itemdict.clear();
   m_nodedict.clear();
 
-  DOM::Node child = pNode.firstChild();
+  try
+  {
+    child = pNode.firstChild();
+  }
+  catch (...)
+  {
+    return;
+  }
+
   while(!child.isNull()) {
     showRecursive(0, child, 0);
     child = child.nextSibling();
@@ -443,7 +455,7 @@ void DOMTreeView::slotSaveClicked()
 
     if (file.exists()) {
       const QString title = i18n( "File exists" );
-      const QString text = i18n( "Do you really want to overwrite: \n%1" ).arg(url.url());
+      const QString text = i18n( "Do you really want to overwrite: \n%1?" ).arg(url.url());
       if (KMessageBox::Yes != KMessageBox::warningYesNoCancel(this, text, title ) ) {
 	return;
       }
@@ -457,8 +469,8 @@ void DOMTreeView::slotSaveClicked()
       kdDebug() << "File closed " << endl;
       delete m_textStream;
     } else {
-      const QString title = i18n( "Couldn't open file" );
-      const QString text = i18n( "Sorry, couldn't open \n %1 \n for writing" ).arg(url.path());
+      const QString title = i18n( "Unable to open file" );
+      const QString text = i18n( "Unable to open \n %1 \n for writing" ).arg(url.path());
       KMessageBox::sorry( this, text, title );
     }
   } else {
@@ -548,6 +560,12 @@ void DOMTreeView::saveRecursive(const DOM::Node &pNode, int indent)
 }
 #endif
 
+void DOMTreeView::updateIncrDecreaseButton()
+{
+    m_decreaseButton->setEnabled((m_expansionDepth > 0));
+    m_increaseButton->setEnabled((m_expansionDepth < m_maxDepth));
+}
+
 void DOMTreeView::slotRefreshClicked()
 {
   slotShowTree(part->document());
@@ -558,6 +576,7 @@ void DOMTreeView::slotIncrExpansionDepth()
   if (m_expansionDepth < m_maxDepth) {
     ++m_expansionDepth;
     adjustDepth(m_rootListView->firstChild(), 0);
+    updateIncrDecreaseButton();
   } else {
     QApplication::beep();
   }
@@ -568,6 +587,7 @@ void DOMTreeView::slotDecrExpansionDepth()
   if (m_expansionDepth > 0) {
     --m_expansionDepth;
     adjustDepth(m_rootListView->firstChild(), 0);
+    updateIncrDecreaseButton();
   } else {
     QApplication::beep();
   }
