@@ -1,4 +1,4 @@
-/* $Id: plugin_domtreeviewer.cpp,v 1.7.2.1 2002/06/14 07:49:43 mlaurent Exp $ */
+/* $Id: plugin_domtreeviewer.cpp,v 1.9 2002/07/16 07:52:15 binner Exp $ */
 
 #include "plugin_domtreeviewer.h"
 
@@ -19,7 +19,7 @@ PluginDomtreeviewer::PluginDomtreeviewer( QObject* parent, const char* name,
 	                                  const QStringList & )
   : Plugin( parent, name )
 {
-  (void) new KAction( i18n("Show &DOM tree"),
+  (void) new KAction( i18n("Show &DOM Tree"),
                       "domtreeviewer", 0,
                       this, SLOT(slotShowDOMTree()),
                       actionCollection(), "viewdomtree" );
