@@ -19,7 +19,7 @@
 
 #include <dcopclient.h>
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <kaction.h>
 #include <kconfig.h>
 #include <kglobal.h>
@@ -52,7 +52,7 @@ SettingsPlugin::SettingsPlugin( QObject* parent, const char* name,
     KToggleAction *action;
 
 
-    action = new KToggleAction( i18n("Java&script"), 0,
+    action = new KToggleAction( i18n("Java&Script"), 0,
 				this, SLOT(toggleJavascript()),
 				actionCollection(), "javascript" );
     menu->insert( action );
@@ -91,7 +91,7 @@ SettingsPlugin::SettingsPlugin( QObject* parent, const char* name,
 
 
     KSelectAction *sAction = new KSelectAction( i18n("Cache Po&licy"), 0,
-						0, 0, actionCollection(), 
+						0, 0, actionCollection(),
                                                 "cachepolicy" );
     QStringList policies;
     policies += i18n( "&Keep Cache in Sync" );
@@ -192,7 +192,7 @@ void SettingsPlugin::toggleCookies()
 	    KMessageBox::sorry( part->widget(),
 				i18n("I can't enable cookies, because the "
 				     "cookie daemon could not be started."),
-				i18n("Cookies disabled"));
+				i18n("Cookies Disabled"));
     }
 }
 
@@ -250,7 +250,7 @@ void SettingsPlugin::toggleProxy()
 {
     bool enable = ((KToggleAction*)actionCollection()->action("useproxy"))->isChecked();
     int t = enable ? KProtocolManager::ManualProxy : KProtocolManager::NoProxy;
-    
+
     KConfig config("kioslaverc", false, false);
     config.setGroup( "Proxy Settings" );
     config.writeEntry( "ProxyType", t );
