@@ -415,7 +415,7 @@ void KImGalleryPlugin::loadCommentFile()
 bool KImGalleryPlugin::createThumb( const QString& imgName, const QString& sourceDirName,
 				    const QString& imgGalleryDir)
 {
-  QPixmap pix;
+  QImage img;
   const QString pixPath = sourceDirName + QString::fromLatin1("/") + imgName;
 
   if (m_copyFiles) {
@@ -436,9 +436,9 @@ bool KImGalleryPlugin::createThumb( const QString& imgName, const QString& sourc
 
   m_imgWidth = 120; // Setting the size of the images is
   m_imgHeight = 90; // required to generate faster 'loading' pages
-  if ( pix.load( pixPath ) )
+  if ( img.load( pixPath ) )
     {
-      int w = pix.width(), h = pix.height();
+      int w = img.width(), h = img.height();
       // scale to pixie size
       // kdDebug() << "w: " << w << " h: " << h << endl;
       // Resizing if to big
@@ -458,16 +458,16 @@ bool KImGalleryPlugin::createThumb( const QString& imgName, const QString& sourc
 	      h = extent;
 	      Q_ASSERT( w <= extent );
             }
-	  const QImage img(pix.convertToImage().smoothScale( w, h ));
-	  if ( img.width() != w || img.height() != h )
+	  const QImage scaleImg(img.smoothScale( w, h ));
+	  if ( scaleImg.width() != w || scaleImg.height() != h )
             {
 	      kdDebug() << "Resizing failed. Aborting." << endl;
 	      return false;
             }
-	  pix.convertFromImage( img );
+	  img = scaleImg;
 	}
       kdDebug() << "Saving thumbnail to: " << thumbDir + imgNamePNG  << endl;
-      if (!pix.save(thumbDir + imgNamePNG, "PNG"))
+      if (!img.save(thumbDir + imgNamePNG, "PNG"))
 	{
 	  kdDebug() << "Saving failed. Aborting." << endl;
 	  return false;
