@@ -40,9 +40,9 @@ private:
 public slots:
     void slotPopupMaeh( );
     void slotStartCopyJob(const QString &path );
-    void slotStartCopyJob(const KURL &url );
+    //void slotStartCopyJob(const KURL &url );
     void slotStartMoveJob(const QString &path );
-    void slotStartMoveJob(const KURL &url );
+    //void slotStartMoveJob(const KURL &url );
     void slotPrepareMenu( );
 };
 
