@@ -17,11 +17,11 @@
  *  Boston, MA 02111-1307, USA.
  **/
 
-/* $Id: plugin_webarchiver.cpp,v 1.23 2002/08/24 23:40:58 cumming Exp $ */
+/* $Id: plugin_webarchiver.cpp,v 1.23.2.1 2003/02/01 09:35:48 lukas Exp $ */
 
-/* 
+/*
  * There are two recursions within this code:
- * - Recursively create DOM-Tree for referenced links which get recursively 
+ * - Recursively create DOM-Tree for referenced links which get recursively
  *   converted to HTML
  *
  * => This code has the potential to download whole sites to a TarGz-Archive
@@ -29,7 +29,7 @@
 
 //#define DEBUG_WAR
 
-#include <assert.h>  
+#include <assert.h>
 
 #include <qdir.h>
 #include <qfile.h>
@@ -38,7 +38,7 @@
 #include <kinstance.h>
 #include <ktempfile.h>
 
-#include <kfiledialog.h>   
+#include <kfiledialog.h>
 #include <kmessagebox.h>
 #include <klocale.h>
 #include <kio/netaccess.h>
@@ -67,12 +67,12 @@ PluginWebArchiver::~PluginWebArchiver()
 }
 
 void PluginWebArchiver::slotSaveToArchive()
-{  
+{
   // ## Unicode ok?
   if( !parent() || !parent()->inherits("KHTMLPart"))
     return;
   KHTMLPart *part = static_cast<KHTMLPart *>( parent() );
-  
+
   QString archiveName = QString::fromUtf8(part->htmlDocument().title().string().utf8());
 
   if (archiveName.isEmpty())
@@ -83,18 +83,19 @@ void PluginWebArchiver::slotSaveToArchive()
 
   archiveName = QDir::homeDirPath() + "/" + archiveName + ".war"; //Thanks ade
 
-  KURL url = KFileDialog::getSaveFileName(archiveName, "*.tgz *.war|Web Archives", part->widget(), 
+  KURL url = KFileDialog::getSaveFileName(archiveName, QString::fromLatin1("*.tgz *.war|")+
+                                          i18n("Web Archives"), part->widget(),
 					  i18n("Save Page as Web-Archive") );
 
   if (url.isEmpty()) { return; }
 
-  if (!(url.isValid())) {  
+  if (!(url.isValid())) {
     const QString title = i18n( "Invalid URL" );
     const QString text = i18n( "This URL \n %1 \n is not valid." ).arg(url.prettyURL());
     KMessageBox::sorry(part->widget(), text, title );
     return;
   }
- 
+
   const QFile file(url.path());
   if (file.exists()) {
     const QString title = i18n( "File exists" );
@@ -104,8 +105,8 @@ void PluginWebArchiver::slotSaveToArchive()
     }
   }
   m_tarBall = new KTarGz(url.path(),"application/x-gzip");
-      
-  if (m_tarBall->open(IO_WriteOnly)) {  
+
+  if (m_tarBall->open(IO_WriteOnly)) {
 #ifdef DEBUG_WAR
     kdDebug() << "Web Archive opened " << endl;
 #endif
@@ -113,51 +114,51 @@ void PluginWebArchiver::slotSaveToArchive()
     // Bookkeeping of downloaded URLs and links
     m_downloadedURLDict = new QDict<QString> ( 17, true );
     m_linkDict = new QDict<QString> ( 17, true );
-   
+
     m_linkDict->insert("index.html", new QString(""));
     saveFile("index.html", part);
- 
+
     delete m_linkDict;
     delete m_downloadedURLDict;
 
     m_tarBall->close();
 
-    KMessageBox::information(part->widget(), i18n( "Archiving webpage completed." ), 
-			     QString::null, QString::null, false);  
+    KMessageBox::information(part->widget(), i18n( "Archiving webpage completed." ),
+			     QString::null, QString::null, false);
 #ifdef DEBUG_WAR
     kdDebug() << "Web Archive closed " << endl;
 #endif
 
   } else {
     const QString title = i18n( "Unable to open Web-Archive" );
-    const QString text = i18n( "Unable to open \n %1 \n for writing." ).arg(url.path());
+    const QString text = i18n( "Unable to open \n %1 \n for writing." ).arg(url.prettyURL());
     KMessageBox::sorry( part->widget(), text, title );
   }
   delete m_tarBall;
 }
- 
+
 /* Store the HTMLized DOM-Tree to a temporary file and add it to the Tar-Ball */
 
 void PluginWebArchiver::saveFile( const QString& fileName,  const KHTMLPart *part)
-{  
-  KTempFile tmpFile;   
+{
+  KTempFile tmpFile;
   if (!(tmpFile.status())) {
     QTextStream* textStream = tmpFile.textStream();
     textStream->setEncoding(QTextStream::Locale);
-    this->saveToArchive(part, textStream);  
+    this->saveToArchive(part, textStream);
 
-    tmpFile.close(); 
+    tmpFile.close();
 
     QFile file(tmpFile.name());
     file.open(IO_ReadOnly);
-    m_tarBall->writeFile(fileName, QString::null, QString::null, file.size(), file.readAll());     
+    m_tarBall->writeFile(fileName, QString::null, QString::null, file.size(), file.readAll());
 #ifdef DEBUG_WAR
     kdDebug() << "HTML-file written: " << fileName << endl;
 #endif
-    file.close(); 
+    file.close();
 
     // Cleaning up
-    file.remove(); 
+    file.remove();
   } else {
     const QString title = i18n( "Couldn't open a temporary file" );
     const QString text = i18n( "Couldn't open a temporary file" );
@@ -170,7 +171,7 @@ void PluginWebArchiver::saveFile( const QString& fileName,  const KHTMLPart *par
 void PluginWebArchiver::saveToArchive(const KHTMLPart *part, QTextStream* _textStream)
 {
   assert(_textStream);
-  
+
   // Add a doctype
 
   (*_textStream) <<"<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\" \"http://www.w3.org/TR/html4/loose.dtd\">" << endl;
@@ -178,7 +179,7 @@ void PluginWebArchiver::saveToArchive(const KHTMLPart *part, QTextStream* _textS
   const DOM::Node &pNode = part->document();
   if(pNode.ownerDocument().isNull()) {
     saveArchiveRecursive(pNode, part->url(), _textStream, 0);
-  } else {    
+  } else {
     saveArchiveRecursive(pNode.ownerDocument(), part->url(), _textStream, 0);
   }
 }
@@ -189,9 +190,9 @@ void PluginWebArchiver::saveArchiveRecursive(const DOM::Node &pNode, const KURL&
 					     QTextStream* _textStream, int indent)
 {
   const QString nodeName(pNode.nodeName().string());
-  QString text; 
+  QString text;
   QString strIndent;
-  strIndent.fill(' ', indent);  
+  strIndent.fill(' ', indent);
   const DOM::Element element = (const DOM::Element) pNode;
   DOM::Node child;
 
@@ -206,7 +207,7 @@ void PluginWebArchiver::saveArchiveRecursive(const DOM::Node &pNode, const KURL&
        * Saving SCRIPT but they can cause trouble!
        */
     } else {
-      if (!m_bPreserveWS) {  
+      if (!m_bPreserveWS) {
 	if (nodeName == "PRE") {
 	  m_bPreserveWS = true;
 	}
@@ -244,10 +245,10 @@ void PluginWebArchiver::saveArchiveRecursive(const DOM::Node &pNode, const KURL&
 	    ((nodeName == "BODY" || nodeName == "TABLE" || nodeName == "TH" || nodeName == "TD") && attrName == "BACKGROUND")) {
 	   // Some people use carriage return in file names and browsers support that!
 	   attrValue = handleLink(baseURL, attrValue.replace(QRegExp("\\s"), ""));
-	} 
+	}
 	/*
 	 * ## Make recursion level configurable
-	 */	 
+	 */
 	/*
 	} else if (nodeName == "A" && attrName == "HREF") {
 	   attrValue = handleLink(baseURL, attrValue);
@@ -276,7 +277,7 @@ void PluginWebArchiver::saveArchiveRecursive(const DOM::Node &pNode, const KURL&
 	text = strIndent + stringToHTML(pNode.nodeValue().string());
       }
     }
-  }   
+  }
 
 #ifdef DEBUG_WAR
   kdDebug() <<  text << endl;
@@ -288,7 +289,7 @@ void PluginWebArchiver::saveArchiveRecursive(const DOM::Node &pNode, const KURL&
     }
   }
 
-  try 
+  try
   {
     // We might throw a DOM exception
     child = pNode.firstChild();
@@ -327,7 +328,7 @@ void PluginWebArchiver::saveArchiveRecursive(const DOM::Node &pNode, const KURL&
 	}
       }
 #ifdef DEBUG_WAR
-      kdDebug() << text << endl;    
+      kdDebug() << text << endl;
 #endif
       if (!(text.isEmpty())) {
 	(*_textStream) << text;
@@ -351,8 +352,8 @@ QString PluginWebArchiver::handleLink(const KURL& _url, const QString& _link)
 #endif
 
   QString fileName;
-  QString tarFileName; 
-  
+  QString tarFileName;
+
   // Only download file once
   if (m_downloadedURLDict->find(url.url())) {
     tarFileName = *m_downloadedURLDict->find(url.url());
@@ -364,13 +365,13 @@ QString PluginWebArchiver::handleLink(const KURL& _url, const QString& _link)
 #ifdef DEBUG_WAR
       kdDebug() << "FileName: " << fileName << endl;
 #endif
-      tarFileName = getUniqueFileName(url.fileName());   
-      
+      tarFileName = getUniqueFileName(url.fileName());
+
       // Add file to Tar-Ball
       QFile file(fileName);
       file.open(IO_ReadOnly);
-      m_tarBall->writeFile(tarFileName, QString::null, QString::null, file.size(), file.readAll());  
-      file.close();  
+      m_tarBall->writeFile(tarFileName, QString::null, QString::null, file.size(), file.readAll());
+      file.close();
 
       // Add URL to downloaded URLs
       m_downloadedURLDict->insert(url.url(), new QString(tarFileName));
@@ -401,8 +402,8 @@ KURL PluginWebArchiver::getAbsoluteURL(const KURL& _url, const QString& _link)
 /* Adds an id to a fileName to make it unique relative to the Tar-Ball */
 
 QString PluginWebArchiver::getUniqueFileName(const QString& fileName)
-{  
-  // Name clash -> add unique id  
+{
+  // Name clash -> add unique id
   static int id;
   QString uniqueFileName(fileName);
 
@@ -410,7 +411,7 @@ QString PluginWebArchiver::getUniqueFileName(const QString& fileName)
   kdDebug() << "getUniqueFileName(..): [" << fileName << "]" << endl;
 #endif
 
-  if (fileName.isEmpty() || m_linkDict->find(fileName)) { 
+  if (fileName.isEmpty() || m_linkDict->find(fileName)) {
     QString strId;
     uniqueFileName = strId.setNum(id) + uniqueFileName;
     id++;
@@ -431,7 +432,7 @@ QString PluginWebArchiver::stringToHTML(const QString& string)
 /* Search for Images in CSS, extract them and adjust CSS */
 
 QString PluginWebArchiver::analyzeInternalCSS(const KURL& _url, const QString& string)
-{ 
+{
 #ifdef DEBUG_WAR
   kdDebug ()  << "analyzeInternalCSS" << endl;
 #endif
@@ -457,20 +458,20 @@ QString PluginWebArchiver::analyzeInternalCSS(const KURL& _url, const QString& s
       if (str[pos-1]=='"' || str[pos-1]=='\'') // CSS 'feature'
 	endUrl--;
       QString url = str.mid(startUrl, endUrl-startUrl);
-      
+
 #ifdef DEBUG_WAR
-      kdDebug () << "url: " << url << endl;    
+      kdDebug () << "url: " << url << endl;
 #endif
-      
+
       url = handleLink(_url, url);
 
 #ifdef DEBUG_WAR
-      kdDebug () << "url: " << url << endl;    
+      kdDebug () << "url: " << url << endl;
 #endif
-      
+
       str = str.replace(startUrl, endUrl-startUrl, url);
       pos++;
-    }  
+    }
   }
   return str;
 }
