@@ -27,17 +27,20 @@ extern "C"
 {
 	Plugin *create_plugin()
 	{
+		KGlobal::locale()->insertCatalogue("pitchablespeed");
 		return new PitchableSpeed();
 	}
 }
 
+const int PitchableSpeed::DEFAULT_OFFSET = 5;
+const int PitchableSpeed::DEFAULT_RANGE = 10;
+
 PitchableSpeed::PitchableSpeed() : Plugin(),
 	offset(DEFAULT_OFFSET),
 	range(DEFAULT_RANGE)
-,	frequenciesPreserved(false),
-	pitchShift(Arts::DynamicCast(napp->player()->engine()->server()->
-								 createObject("Arts::Synth_STEREO_PITCH_SHIFT")))
+,	frequenciesPreserved(false)
 {
+	
 	rangeInput->setRange(2,150,1,false);
 	rangeInput->setValue(range);
 	offsetInput->setRange(-5,15,1,false);
@@ -48,7 +51,6 @@ PitchableSpeed::PitchableSpeed() : Plugin(),
 	connect(preserveFrequencies, SIGNAL(toggled(bool)),
 			this, SLOT(preserveFrequenciesChanged(bool)));
 	//show();
-	pitchShift.frequency(10.f); // TODO: might have to experiment a bit with this
 }
 
 PitchableSpeed::~PitchableSpeed()
@@ -104,7 +106,7 @@ void PitchableSpeed::setupSliderRange()
 	slider->setTickInterval(10);
 }
 
-void PitchableSpeed::speedChanged(int newSpeed)
+void PitchableSpeed::speedChanged(int )
 {
 	setSpeed();
 }
@@ -127,6 +129,9 @@ void PitchableSpeed::preserveFrequenciesChanged(bool preserveNow)
 		return;
 	if (preserveNow)
 	{
+		pitchShift = Arts::DynamicCast(napp->player()->engine()->server()->
+				 createObject("Arts::Synth_STEREO_PITCH_SHIFT"));
+		pitchShift.frequency(10.f); // TODO: might have to experiment a bit with this
 		pitchShift.speed(1.f/sliderSpeed());
 		pitchShift.start();
 		pitchShiftEffectID= napp->player()->engine()->effectStack()->
@@ -136,6 +141,7 @@ void PitchableSpeed::preserveFrequenciesChanged(bool preserveNow)
 	{
 		napp->player()->engine()->effectStack()->remove(pitchShiftEffectID);
 		pitchShift.stop();
+		pitchShift = Arts::Synth_STEREO_PITCH_SHIFT::null();
 	}
 	frequenciesPreserved= preserveNow;
 }
@@ -148,10 +154,8 @@ void PitchableSpeed::init()
 
 void PitchableSpeed::toggle(void)
 {
-	if(isHidden())
-		show();
-	else
-		hide();
+	show();
+	raise();
 }
 
 void PitchableSpeed::closeEvent(QCloseEvent *)
