@@ -8,12 +8,13 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kprocess.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <noatun/app.h>
 #include <kdebug.h>
 
 extern "C" Plugin *create_plugin()
 {
+	KGlobal::locale()->insertCatalogue("tyler");
 	return new Tyler();
 }
 
@@ -41,7 +42,7 @@ void Tyler::init()
 	// for two separate checks.
 	if(!process.start(KProcess::NotifyOnExit, (KProcess::Communication)(KProcess::Stdin | KProcess::Stdout)))
 	{
-		KMessageBox::error(0, i18n("Could not start noatuntyler.bin.  Check your installation."));
+		KMessageBox::error(0, i18n("Unable to start noatuntyler.bin. Check your installation."));
 		unload();
 	}
 	else
